@@ -211,7 +211,7 @@ class AnalysisTests(unittest.TestCase):
                 r = Analysis.from_xml(f)
                 num_analyses += 1
         # Ensure that all of the reports were indeed parsed:
-        self.assertEqual(num_analyses, 9)
+        self.assertEqual(num_analyses, 10)
 
     def test_example_2(self):
         # Verify that the parser works:
@@ -293,7 +293,8 @@ class AnalysisTests(unittest.TestCase):
                              'register_all_py_protocols_func')
             self.assertEqual(w.location.line, 159)
             self.assertEqual(w.location.column, 42)
-            self.assert_(w.customfields['traceback'].startswith('wspy_register.c: In function \'register_all_py_protocols_func\':\n'))
+            self.assertTrue(w.customfields['traceback']
+                            .startswith('wspy_register.c: In function \'register_all_py_protocols_func\':\n'))
 
     def test_example_5(self):
         # Ensure that we can load range information from XML
@@ -418,10 +419,13 @@ class AnalysisTests(unittest.TestCase):
         self.assertEqual(a9, a10)
 
     def test_json_roundtrip(self):
+        verbose = False
+
         def roundtrip_through_json(a):
             jsondict = a.to_json()
-            from pprint import pprint
-            pprint(jsondict)
+            if verbose:
+                from pprint import pprint
+                pprint(jsondict)
             return Analysis.from_json(jsondict)
 
         a1, w = self.make_simple_analysis()
